==> opensaml-core-3.4.5-sources.jar: org/opensaml/core/xml/schema/impl/XSDateTimeUnmarshaller.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.core.xml.schema.impl;

import org.joda.time.DateTime;
import org.joda.time.chrono.ISOChronology;
import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.BaseXMLObjectUnmarshaller;
import org.opensaml.core.xml.schema.XSDateTime;

/**
 * Thread-safe unmarshaller for {@link org.opensaml.core.xml.schema.XSDateTime} objects.
 */
public class XSDateTimeUnmarshaller extends BaseXMLObjectUnmarshaller{
    
    /** Constructor. */
    public XSDateTimeUnmarshaller(){}

    /** {@inheritDoc} */
    protected void processElementContent(final XMLObject xmlObject, final String elementContent) {
        final XSDateTime xsDateTime = (XSDateTime) xmlObject;
        
        xsDateTime.setValue(new DateTime(elementContent).withChronology(ISOChronology.getInstanceUTC()));
    }

}

==> opensaml-core-4.1.1-sources.jar: org/opensaml/core/xml/schema/impl/XSDateTimeUnmarshaller.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.core.xml.schema.impl;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.AbstractXMLObjectUnmarshaller;
import org.opensaml.core.xml.schema.XSDateTime;

import net.shibboleth.utilities.java.support.xml.DOMTypeSupport;

/**
 * Thread-safe unmarshaller for {@link XSDateTime} objects.
 */
public class XSDateTimeUnmarshaller extends AbstractXMLObjectUnmarshaller{

    /** {@inheritDoc} */
    protected void processElementContent(final XMLObject xmlObject, final String elementContent) {
        final XSDateTime xsDateTime = (XSDateTime) xmlObject;
        
        xsDateTime.setValue(DOMTypeSupport.stringToInstant(elementContent));
    }

}
